pub struct DnsServerWatcherProxy { /* private fields */ }Implementations
Sourceimpl DnsServerWatcherProxy
impl DnsServerWatcherProxy
Sourcepub fn take_event_stream(&self) -> DnsServerWatcherEventStream
pub fn take_event_stream(&self) -> DnsServerWatcherEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch_servers(
&self,
) -> QueryResponseFut<Vec<DnsServer_>, FDomainResourceDialect>
pub fn watch_servers( &self, ) -> QueryResponseFut<Vec<DnsServer_>, FDomainResourceDialect>
Returns a list of DNS servers.
First call always returns a snapshot of the current list of servers or blocks if an empty list would be returned. Subsequent calls will block until the list of servers changes.
The list of servers changes over time by configuration or network topology changes,
expiration, etc. Callers must repeatedly call WatchServers and replace any previously
returned servers with new ones to avoid using stale or expired entries.
It is invalid to call this method while a previous call is pending. Doing so will cause the server end of the protocol to be closed.
- response
serversThe list of servers to use for DNS resolution, in priority order.